pub enum CodeChangeKind<BlockNumber> {
Active {
expiration: Option<BlockNumber>,
},
Inactive,
Reinstrumented,
}Expand description
Type of changes applied to code in storage.
Variants
Active
Code become active and ready for use.
Appear when new code created or expiration block number updated.
Expiration block number presents block number when this code become
inactive due to losing ability to pay rent for holding.
Equals None if stores free (some program relays on it, see #646).
Inactive
Code become inactive and can no longer be used.
Reinstrumented
Code was reinstrumented.