pub enum MessageWokenSystemReason {
ProgramGotInitialized,
TimeoutHasCome,
OutOfRent,
}Expand description
System reason for messages waking.
Variants
ProgramGotInitialized
Program had finished initialization.
Note that this variant doesn’t contain info about initialization success or failure.
TimeoutHasCome
Specified by program timeout for waking has come (see #349).
OutOfRent
Message can no longer pay rent for holding in storage (see #646).