ProgramChangeKind

Enum ProgramChangeKind 

pub enum ProgramChangeKind<BlockNumber> {
    Active {
        expiration: BlockNumber,
    },
    Inactive,
    Paused,
    Terminated,
    ExpirationChanged {
        expiration: BlockNumber,
    },
    ProgramSet {
        expiration: BlockNumber,
    },
}
Type of changes applied to program in storage.

Variants



Active

Active status achieved.

Occurs when new program created or paused program was resumed.

Expiration block number presents block number when this program become paused due to losing ability to pay rent for holding.

Fields

expiration: BlockNumber


Inactive

Program become inactive forever due to gr_exit call.



Paused

Paused status.

Program is no longer available for interaction, but can be resumed by paying rent and giving whole data related to it.



Terminated

Program become inactive forever due to init failure.



ExpirationChanged

Occurs when expiration block number of a program changed.

Expiration block number presents block number when this program become paused due to losing ability to pay rent for holding.

Fields

expiration: BlockNumber


ProgramSet

Occurs when new program set in the storage.

Expiration block number presents block number when this program become paused due to losing ability to pay rent for holding or terminated in case of didn’t get initialised.

Fields

expiration: BlockNumber