pub enum Reason<R: RuntimeReason, S: SystemReason> {
Runtime(R),
System(S),
}Expand description
Composite reason type for any action happened on chain.
Variants
Runtime(R)
Runtime reason variant.
This means that actor explicitly forced some action, which this reason explains.
System(S)
System reason variant.
This means that system automatically forced some action, which this reason explains.