pub type UserMessageReadReason = Reason<UserMessageReadRuntimeReason, UserMessageReadSystemReason>;Expand description
Composite reason for messages reading from Mailbox.
Aliased Type
pub enum UserMessageReadReason {
Runtime(UserMessageReadRuntimeReason),
System(UserMessageReadSystemReason),
}Variants
Runtime(UserMessageReadRuntimeReason)
Runtime reason variant.
This means that actor explicitly forced some action, which this reason explains.
System(UserMessageReadSystemReason)
System reason variant.
This means that system automatically forced some action, which this reason explains.