pub struct TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>(/* private fields */);Trait Implementations
Sourceimpl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> LockableTree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
impl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> LockableTree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
Sourcefn lock(
key: impl Into<Self::NodeId>,
id: LockId,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn lock( key: impl Into<Self::NodeId>, id: LockId, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourcefn unlock(
key: impl Into<Self::NodeId>,
id: LockId,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn unlock( key: impl Into<Self::NodeId>, id: LockId, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourceimpl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> ReservableTree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
impl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> ReservableTree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
Sourcefn reserve(
key: impl Into<Self::NodeId>,
new_key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn reserve( key: impl Into<Self::NodeId>, new_key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourcefn system_reserve(
key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn system_reserve( key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourceimpl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> Tree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
impl<TotalValue, Balance, Funds, InternalError, Error, ExternalId, NodeId, StorageMap> Tree for TreeImpl<TotalValue, InternalError, Error, ExternalId, NodeId, StorageMap>where
Balance: BalanceTrait,
Funds: Clone,
TotalValue: ValueStorage<Value = Balance>,
InternalError: Error,
Error: From<InternalError>,
ExternalId: Clone,
NodeId: Copy,
StorageMap: MapStorage<Key = NodeId, Value = GasNode<ExternalId, NodeId, Balance, Funds>>,
Sourcefn consume(key: impl Into<Self::NodeId>) -> ConsumeResultOf<Self>
fn consume(key: impl Into<Self::NodeId>) -> ConsumeResultOf<Self>
Marks a node with key as consumed, if possible, and tries to return
it’s value and delete it. The function performs same procedure with all
the nodes on the path from it to the root, if possible.
Marking a node as consumed is possible only for GasNode::External
and GasNode::SpecifiedLocal nodes. That is because these nodes can
be not deleted after the function call, because of, for instance,
having children refs. Such nodes as GasNode::UnspecifiedLocal
and GasNode::ReservedLocal are removed when the function is
called, so there is no need for marking them as consumed.
When consuming the node, it’s value is mutated by calling catch_value,
which tries to either return or move value upstream if possible.
Read the catch_value function’s documentation for details.
To delete node, here should be two requirements:
Self::consumewas called on the node.- The node has no children, i.e. spec/unspec refs.
So if it’s impossible to delete a node, then it’s impossible to delete its parent in the current call. Also if it’s possible to delete a node, then it doesn’t necessarily mean that its parent will be deleted. An example here could be the case, when during async execution original message went to wait list, so wasn’t consumed but the one generated during the execution of the original message went to message queue and was successfully executed.
Sourcefn spend(
key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<Self::NegativeImbalance, Self::Error>
fn spend( key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<Self::NegativeImbalance, Self::Error>
Spends amount of gas from the ancestor of node with key id.
Calling the function is possible even if an ancestor is consumed.
Note:
Node is considered as an ancestor of itself.
Sourcetype ExternalOrigin = ExternalId
type ExternalOrigin = ExternalId
Sourcetype PositiveImbalance = PositiveImbalance<Balance>
type PositiveImbalance = PositiveImbalance<Balance>
PositiveImbalance indicates that some value has been added
to circulation , i.e. total supply has increased.Sourcetype NegativeImbalance = NegativeImbalance<Balance>
type NegativeImbalance = NegativeImbalance<Balance>
NegativeImbalance indicates that some value has been removed
from circulation, i.e. total supply has decreased.type InternalError = InternalError
Sourcefn total_supply() -> Self::Balance
fn total_supply() -> Self::Balance
Sourcefn create(
origin: Self::ExternalOrigin,
multiplier: GasMultiplier<Self::Funds, Self::Balance>,
key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<Self::PositiveImbalance, Self::Error>
fn create( origin: Self::ExternalOrigin, multiplier: GasMultiplier<Self::Funds, Self::Balance>, key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<Self::PositiveImbalance, Self::Error>
amount of it and attributing it to the origin. Read moreSourcefn get_origin_node(
key: impl Into<Self::NodeId>,
) -> Result<OriginNodeDataOf<Self>, Self::Error>
fn get_origin_node( key: impl Into<Self::NodeId>, ) -> Result<OriginNodeDataOf<Self>, Self::Error>
Sourcefn get_limit_node(
key: impl Into<Self::NodeId>,
) -> Result<(Self::Balance, Self::NodeId), Self::Error>
fn get_limit_node( key: impl Into<Self::NodeId>, ) -> Result<(Self::Balance, Self::NodeId), Self::Error>
Sourcefn get_limit_node_consumed(
key: impl Into<Self::NodeId>,
) -> Result<(Self::Balance, Self::NodeId), Self::Error>
fn get_limit_node_consumed( key: impl Into<Self::NodeId>, ) -> Result<(Self::Balance, Self::NodeId), Self::Error>
Sourcefn split_with_value(
key: impl Into<Self::NodeId>,
new_key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn split_with_value( key: impl Into<Self::NodeId>, new_key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourcefn split(
key: impl Into<Self::NodeId>,
new_key: impl Into<Self::NodeId>,
) -> Result<(), Self::Error>
fn split( key: impl Into<Self::NodeId>, new_key: impl Into<Self::NodeId>, ) -> Result<(), Self::Error>
Sourcefn cut(
key: impl Into<Self::NodeId>,
new_key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn cut( key: impl Into<Self::NodeId>, new_key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourcefn create_deposit(
key: impl Into<Self::NodeId>,
new_key: impl Into<Self::NodeId>,
amount: Self::Balance,
) -> Result<(), Self::Error>
fn create_deposit( key: impl Into<Self::NodeId>, new_key: impl Into<Self::NodeId>, amount: Self::Balance, ) -> Result<(), Self::Error>
Sourcefn exists_and_deposit(key: impl Into<Self::NodeId>) -> bool
fn exists_and_deposit(key: impl Into<Self::NodeId>) -> bool
Sourcefn get_external(
key: impl Into<Self::NodeId>,
) -> Result<Self::ExternalOrigin, Self::Error>
fn get_external( key: impl Into<Self::NodeId>, ) -> Result<Self::ExternalOrigin, Self::Error>
Sourcefn get_funds_multiplier(
key: impl Into<Self::NodeId>,
) -> Result<GasMultiplier<Self::Funds, Self::Balance>, Self::Error>
fn get_funds_multiplier( key: impl Into<Self::NodeId>, ) -> Result<GasMultiplier<Self::Funds, Self::Balance>, Self::Error>
Sourcefn get_origin_key(
key: impl Into<Self::NodeId>,
) -> Result<Self::NodeId, Self::Error>
fn get_origin_key( key: impl Into<Self::NodeId>, ) -> Result<Self::NodeId, Self::Error>