DequeueImpl

Struct DequeueImpl 

pub struct DequeueImpl<Key, Value, Error, HVS, TVS, MS, Callbacks>(/* private fields */)
where
    Key: Clone + PartialEq,
    Error: DequeueError,
    HVS: ValueStorage<Value = Key>,
    TVS: ValueStorage<Value = Key>,
    MS: MapStorage<Key = Key, Value = LinkedNode<Key, Value>>,
    Callbacks: DequeueCallbacks<Value = Value>;
Dequeue implementation based on MapStorage and ValueStorages.

Generic parameters Key and Value specify data and keys for storing. Generic parameter Error requires DequeueError implementation. Generic parameter Callbacks presents actions for success operations over dequeue.