DequeueError

Trait DequeueError 

pub trait DequeueError {
    // Required methods
    fn duplicate_key() -> Self;
    fn element_not_found() -> Self;
    fn head_should_be_set() -> Self;
    fn head_should_not_be_set() -> Self;
    fn tail_has_next_key() -> Self;
    fn tail_parent_not_found() -> Self;
    fn tail_should_be_set() -> Self;
    fn tail_should_not_be_set() -> Self;
}
Represents dequeue error type.

Contains constructors for all existing errors.

Required Methods

fn duplicate_key() -> Self

Occurs when given key already exists in dequeue.

fn element_not_found() -> Self

Occurs when element wasn’t found in storage.

fn head_should_be_set() -> Self

Occurs when head should contain value, but it’s empty for some reason.

fn head_should_not_be_set() -> Self

Occurs when head should be empty, but it contains value for some reason.

fn tail_has_next_key() -> Self

Occurs when tail element of the dequeue contains link to the next element.

fn tail_parent_not_found() -> Self

Occurs when while searching pre-tail, element wasn’t found.

fn tail_should_be_set() -> Self

Occurs when tail should contain value, but it’s empty for some reason.

fn tail_should_not_be_set() -> Self

Occurs when tail should be empty, but it contains value for some reason.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors