WaitlistCallbacks

Trait WaitlistCallbacks 

pub trait WaitlistCallbacks {
    type Value;
    type BlockNumber;
    type GetBlockNumber: GetCallback<Self::BlockNumber>;
    type OnInsert: Callback<(Self::Value, Interval<Self::BlockNumber>)>;
    type OnRemove: Callback<(Self::Value, Interval<Self::BlockNumber>)>;
}
Represents store of waitlist’s action callbacks.

Required Associated Types

type Value

Callback relative type.

This value represents main stored component in waitlist, which uses this callbacks store.

type BlockNumber

Callback relative type.

This type represents block number of stored component in waitlist, which uses this callbacks store.

type GetBlockNumber: GetCallback<Self::BlockNumber>

Callback used for getting current block number.

type OnInsert: Callback<(Self::Value, Interval<Self::BlockNumber>)>

Callback on success insert.

type OnRemove: Callback<(Self::Value, Interval<Self::BlockNumber>)>

Callback on success remove.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors