pub trait WaitlistCallbacks {
type Value;
type BlockNumber;
type GetBlockNumber: GetCallback<Self::BlockNumber>;
type OnInsert: Callback<(Self::Value, Interval<Self::BlockNumber>)>;
type OnRemove: Callback<(Self::Value, Interval<Self::BlockNumber>)>;
}Expand description
Represents store of waitlist’s action callbacks.
Required Associated Types
Sourcetype Value
type Value
Callback relative type.
This value represents main stored component in waitlist, which uses this callbacks store.
Sourcetype BlockNumber
type BlockNumber
Callback relative type.
This type represents block number of stored component in waitlist, which uses this callbacks store.
Sourcetype GetBlockNumber: GetCallback<Self::BlockNumber>
type GetBlockNumber: GetCallback<Self::BlockNumber>
Callback used for getting current block number.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".