BlockLimiter

Trait BlockLimiter 

pub trait BlockLimiter {
    type BlockGasLimit: Get<Self::Balance>;
    type Balance;
    type GasAllowance: Limiter<Value = Self::Balance>;
}
Contains various limits for the block.

Required Associated Types

type BlockGasLimit: Get<Self::Balance>

The maximum amount of gas that can be used within a single block.

type Balance

Type representing a quantity of value.

type GasAllowance: Limiter<Value = Self::Balance>

Type manages a gas that is available at the moment of call.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors